<?php

namespace App\Api\V1\Responses;

/**
 * Classe utilitaire pour les réponses API standardisées.
 */
class ApiResponse
{
    /**
     * Envoie une réponse de succès.
     */
    public static function success($data = null, $message = 'Success', $statusCode = 200)
    {
        http_response_code($statusCode);
        header('Content-Type: application/json');
        
        $response = [
            'success' => true,
            'message' => $message,
        ];
        
        if ($data !== null) {
            $response['data'] = $data;
        }
        
        echo json_encode($response, JSON_UNESCAPED_UNICODE);
        exit;
    }

    /**
     * Envoie une réponse de création réussie.
     */
    public static function created($data = null, $message = 'Created successfully')
    {
        return self::success($data, $message, 201);
    }

    /**
     * Envoie une réponse d'erreur.
     */
    public static function error($message = 'An error occurred', $statusCode = 400, $errors = null)
    {
        http_response_code($statusCode);
        header('Content-Type: application/json');
        
        $response = [
            'success' => false,
            'message' => $message,
        ];
        
        if ($errors !== null) {
            $response['errors'] = $errors;
        }
        
        echo json_encode($response, JSON_UNESCAPED_UNICODE);
        exit;
    }

    /**
     * Réponse d'erreur 400 - Bad Request.
     */
    public static function badRequest($message = 'Bad Request', $errors = null)
    {
        return self::error($message, 400, $errors);
    }

    /**
     * Réponse d'erreur 401 - Unauthorized.
     */
    public static function unauthorized($message = 'Unauthorized')
    {
        return self::error($message, 401);
    }

    /**
     * Réponse d'erreur 403 - Forbidden.
     */
    public static function forbidden($message = 'Forbidden')
    {
        return self::error($message, 403);
    }

    /**
     * Réponse d'erreur 404 - Not Found.
     */
    public static function notFound($message = 'Not Found')
    {
        return self::error($message, 404);
    }

    /**
     * Réponse d'erreur 405 - Method Not Allowed.
     */
    public static function methodNotAllowed($message = 'Method Not Allowed')
    {
        return self::error($message, 405);
    }

    /**
     * Réponse d'erreur 422 - Unprocessable Entity.
     */
    public static function unprocessableEntity($message = 'Validation failed', $errors = null)
    {
        return self::error($message, 422, $errors);
    }

    /**
     * Réponse d'erreur 500 - Internal Server Error.
     */
    public static function serverError($message = 'Internal Server Error', $errors = null)
    {
        return self::error($message, 500, $errors);
    }
}